/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { KENDO_GRID_COLUMN_DRAGANDDROP, KENDO_GRID_COLUMN_MENU_DECLARATIONS, KENDO_GRID_FILTER_MENU, KENDO_GRID_FILTER_ROW, KENDO_GRID_GROUP_EXPORTS, KENDO_GRID_HEADER_EXPORTS, KENDO_GRID_SHARED } from '../../directives';
import { DialogContainerService, DialogService, WindowContainerService, WindowService } from '@progress/kendo-angular-dialog';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, NavigationService, YearViewService } from '@progress/kendo-angular-dateinputs';
import * as i0 from "@angular/core";
import * as i1 from "../../grouping/group-header-template.directive";
import * as i2 from "../../grouping/group-header-column-template.directive";
import * as i3 from "../../grouping/group-footer-template.directive";
import * as i4 from "../../grouping/group-header.component";
import * as i5 from "../../grouping/group-panel.component";
import * as i6 from "../../filtering/filter-row.component";
import * as i7 from "../../filtering/cell/filter-cell.component";
import * as i8 from "../../filtering/cell/filter-cell-template.directive";
import * as i9 from "../../filtering/cell/string-filter-cell.component";
import * as i10 from "../../filtering/cell/numeric-filter-cell.component";
import * as i11 from "../../filtering/cell/autocomplete-filter-cell.component";
import * as i12 from "../../filtering/cell/boolean-filter-cell.component";
import * as i13 from "../../filtering/cell/filter-cell-host.directive";
import * as i14 from "../../filtering/cell/filter-cell-wrapper.component";
import * as i15 from "../../filtering/cell/date-filter-cell.component";
import * as i16 from "../../columns/column.component";
import * as i17 from "../../columns/column-group.component";
import * as i18 from "../../navigation/logical-cell.directive";
import * as i19 from "../../navigation/logical-row.directive";
import * as i20 from "../../navigation/focusable.directive";
import * as i21 from "../footer/footer-template.directive";
import * as i22 from "../common/col-group.component";
import * as i23 from "../../layout/resizable.directive";
import * as i24 from "@progress/kendo-angular-common";
import * as i25 from "../common/field-accessor.pipe";
import * as i26 from "../details/detail-template.directive";
import * as i27 from "../../columns/span-column.component";
import * as i28 from "../common/loading.component";
import * as i29 from "../grid-table.directive";
import * as i30 from "../../filtering/cell/filter-cell-operators.component";
import * as i31 from "../../filtering/operators/contains-filter-operator.component";
import * as i32 from "../../filtering/operators/not-contains-filter-operator.component";
import * as i33 from "../../filtering/operators/ends-with-filter-operator.component";
import * as i34 from "../../filtering/operators/eq-filter-operator.component";
import * as i35 from "../../filtering/operators/is-empty-filter-operator.component";
import * as i36 from "../../filtering/operators/is-not-empty-filter-operator.component";
import * as i37 from "../../filtering/operators/is-not-null-filter-operator.component";
import * as i38 from "../../filtering/operators/isnull-filter-operator.component";
import * as i39 from "../../filtering/operators/neq-filter-operator.component";
import * as i40 from "../../filtering/operators/starts-with-filter-operator.component";
import * as i41 from "../../filtering/operators/gt-filter-operator.component";
import * as i42 from "../../filtering/operators/gte-filter-operator.component";
import * as i43 from "../../filtering/operators/lt-filter-operator.component";
import * as i44 from "../../filtering/operators/lte-filter-operator.component";
import * as i45 from "../../filtering/operators/after-filter-operator.component";
import * as i46 from "../../filtering/operators/after-eq-filter-operator.component";
import * as i47 from "../../filtering/operators/before-eq-filter-operator.component";
import * as i48 from "../../filtering/operators/before-filter-operator.component";
import * as i49 from "../../filtering/filter-input.directive";
import * as i50 from "../../filtering/menu/filter-menu.component";
import * as i51 from "../../filtering/menu/filter-menu-container.component";
import * as i52 from "../../filtering/menu/filter-menu-input-wrapper.component";
import * as i53 from "../../filtering/menu/string-filter-menu-input.component";
import * as i54 from "../../filtering/menu/string-filter-menu.component";
import * as i55 from "../../filtering/menu/filter-menu-template.directive";
import * as i56 from "../../filtering/menu/numeric-filter-menu.component";
import * as i57 from "../../filtering/menu/numeric-filter-menu-input.component";
import * as i58 from "../../filtering/menu/date-filter-menu-input.component";
import * as i59 from "../../filtering/menu/date-filter-menu.component";
import * as i60 from "../../filtering/menu/filter-menu-host.directive";
import * as i61 from "../../filtering/menu/boolean-filter-menu.component";
import * as i62 from "../../filtering/menu/filter-menu-dropdownlist.directive";
import * as i63 from "../../filtering/menu/filter-radio-button.directive";
import * as i64 from "../../dragdrop/draggable-column.directive";
import * as i65 from "../../dragdrop/drop-target.directive";
import * as i66 from "../../column-menu/column-chooser-item-checked.directive";
import * as i67 from "../../column-menu/column-list.component";
import * as i68 from "../../column-menu/column-chooser.component";
import * as i69 from "../../column-menu/column-menu-chooser.component";
import * as i70 from "../../column-menu/column-menu-filter.component";
import * as i71 from "../../column-menu/column-menu-item.component";
import * as i72 from "../../column-menu/column-menu-item-content-template.directive";
import * as i73 from "../../column-menu/column-menu-sort.component";
import * as i74 from "../../column-menu/column-menu.component";
import * as i75 from "../../column-menu/column-menu-lock.component";
import * as i76 from "../../column-menu/column-menu-template.directive";
import * as i77 from "../../column-menu/column-menu-container.component";
import * as i78 from "../../column-menu/column-menu-item.directive";
import * as i79 from "../../column-menu/column-menu-stick.component";
import * as i80 from "../../column-menu/column-menu-position.component";
import * as i81 from "../../column-menu/column-menu-autosize.component";
import * as i82 from "../../column-menu/column-menu-autosize-all.component";
import * as i83 from "./header.component";
import * as i84 from "./header-template.directive";
import * as i85 from "../../column-resizing/column-handle.directive";
import * as i86 from "../../selection/selectall-checkbox.directive";
const importedModules = [
    ...KENDO_GRID_GROUP_EXPORTS,
    ...KENDO_GRID_FILTER_ROW,
    ...KENDO_GRID_FILTER_MENU,
    ...KENDO_GRID_SHARED,
    ...KENDO_GRID_COLUMN_DRAGANDDROP,
    ...KENDO_GRID_COLUMN_MENU_DECLARATIONS
];
/**
 * @hidden
 *
 * This module is deprecated and will be removed in a future major version release.
 */
export class HeaderModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HeaderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: HeaderModule, imports: [i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.FilterRowComponent, i7.FilterCellComponent, i8.FilterCellTemplateDirective, i9.StringFilterCellComponent, i10.NumericFilterCellComponent, i11.AutoCompleteFilterCellComponent, i12.BooleanFilterCellComponent, i13.FilterCellHostDirective, i14.FilterCellWrapperComponent, i15.DateFilterCellComponent, i16.ColumnComponent, i17.ColumnGroupComponent, i18.LogicalCellDirective, i19.LogicalRowDirective, i20.FocusableDirective, i21.FooterTemplateDirective, i22.ColGroupComponent, i23.ResizableContainerDirective, i24.TemplateContextDirective, i25.FieldAccessorPipe, i26.DetailTemplateDirective, i27.SpanColumnComponent, i28.LoadingComponent, i29.GridTableDirective, i30.FilterCellOperatorsComponent, i31.ContainsFilterOperatorComponent, i32.DoesNotContainFilterOperatorComponent, i33.EndsWithFilterOperatorComponent, i34.EqualFilterOperatorComponent, i35.IsEmptyFilterOperatorComponent, i36.IsNotEmptyFilterOperatorComponent, i37.IsNotNullFilterOperatorComponent, i38.IsNullFilterOperatorComponent, i39.NotEqualFilterOperatorComponent, i40.StartsWithFilterOperatorComponent, i41.GreaterFilterOperatorComponent, i42.GreaterOrEqualToFilterOperatorComponent, i43.LessFilterOperatorComponent, i44.LessOrEqualToFilterOperatorComponent, i45.AfterFilterOperatorComponent, i46.AfterEqFilterOperatorComponent, i47.BeforeEqFilterOperatorComponent, i48.BeforeFilterOperatorComponent, i49.FilterInputDirective, i16.ColumnComponent, i17.ColumnGroupComponent, i18.LogicalCellDirective, i19.LogicalRowDirective, i20.FocusableDirective, i21.FooterTemplateDirective, i22.ColGroupComponent, i23.ResizableContainerDirective, i24.TemplateContextDirective, i25.FieldAccessorPipe, i26.DetailTemplateDirective, i27.SpanColumnComponent, i28.LoadingComponent, i29.GridTableDirective, i30.FilterCellOperatorsComponent, i31.ContainsFilterOperatorComponent, i32.DoesNotContainFilterOperatorComponent, i33.EndsWithFilterOperatorComponent, i34.EqualFilterOperatorComponent, i35.IsEmptyFilterOperatorComponent, i36.IsNotEmptyFilterOperatorComponent, i37.IsNotNullFilterOperatorComponent, i38.IsNullFilterOperatorComponent, i39.NotEqualFilterOperatorComponent, i40.StartsWithFilterOperatorComponent, i41.GreaterFilterOperatorComponent, i42.GreaterOrEqualToFilterOperatorComponent, i43.LessFilterOperatorComponent, i44.LessOrEqualToFilterOperatorComponent, i45.AfterFilterOperatorComponent, i46.AfterEqFilterOperatorComponent, i47.BeforeEqFilterOperatorComponent, i48.BeforeFilterOperatorComponent, i49.FilterInputDirective, i50.FilterMenuComponent, i51.FilterMenuContainerComponent, i52.FilterMenuInputWrapperComponent, i53.StringFilterMenuInputComponent, i54.StringFilterMenuComponent, i55.FilterMenuTemplateDirective, i56.NumericFilterMenuComponent, i57.NumericFilterMenuInputComponent, i58.DateFilterMenuInputComponent, i59.DateFilterMenuComponent, i60.FilterMenuHostDirective, i61.BooleanFilterMenuComponent, i62.FilterMenuDropDownListDirective, i63.BooleanFilterRadioButtonDirective, i16.ColumnComponent, i17.ColumnGroupComponent, i18.LogicalCellDirective, i19.LogicalRowDirective, i20.FocusableDirective, i21.FooterTemplateDirective, i22.ColGroupComponent, i23.ResizableContainerDirective, i24.TemplateContextDirective, i25.FieldAccessorPipe, i26.DetailTemplateDirective, i27.SpanColumnComponent, i28.LoadingComponent, i29.GridTableDirective, i64.DraggableColumnDirective, i65.DropTargetDirective, i66.ColumnMenuChooserItemCheckedDirective, i67.ColumnListComponent, i68.ColumnChooserComponent, i69.ColumnMenuChooserComponent, i70.ColumnMenuFilterComponent, i71.ColumnMenuItemComponent, i72.ColumnMenuItemContentTemplateDirective, i73.ColumnMenuSortComponent, i74.ColumnMenuComponent, i75.ColumnMenuLockComponent, i76.ColumnMenuTemplateDirective, i77.ColumnMenuContainerComponent, i78.ColumnMenuItemDirective, i79.ColumnMenuStickComponent, i80.ColumnMenuPositionComponent, i81.ColumnMenuAutoSizeColumnComponent, i82.ColumnMenuAutoSizeAllColumnsComponent, i83.HeaderComponent, i84.HeaderTemplateDirective, i85.ColumnHandleDirective, i86.SelectAllCheckboxDirective], exports: [i83.HeaderComponent, i84.HeaderTemplateDirective, i85.ColumnHandleDirective, i86.SelectAllCheckboxDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HeaderModule, providers: [
            PopupService,
            ResizeBatchService,
            IconsService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService,
            CalendarDOMService,
            CenturyViewService,
            DecadeViewService,
            MonthViewService,
            YearViewService,
            NavigationService
        ], imports: [i4.GroupHeaderComponent, i5.GroupPanelComponent, i9.StringFilterCellComponent, i10.NumericFilterCellComponent, i11.AutoCompleteFilterCellComponent, i12.BooleanFilterCellComponent, i14.FilterCellWrapperComponent, i15.DateFilterCellComponent, i30.FilterCellOperatorsComponent, i30.FilterCellOperatorsComponent, i50.FilterMenuComponent, i51.FilterMenuContainerComponent, i52.FilterMenuInputWrapperComponent, i53.StringFilterMenuInputComponent, i54.StringFilterMenuComponent, i56.NumericFilterMenuComponent, i57.NumericFilterMenuInputComponent, i58.DateFilterMenuInputComponent, i59.DateFilterMenuComponent, i68.ColumnChooserComponent, i69.ColumnMenuChooserComponent, i70.ColumnMenuFilterComponent, i71.ColumnMenuItemComponent, i73.ColumnMenuSortComponent, i74.ColumnMenuComponent, i75.ColumnMenuLockComponent, i79.ColumnMenuStickComponent, i80.ColumnMenuPositionComponent, i81.ColumnMenuAutoSizeColumnComponent, i82.ColumnMenuAutoSizeAllColumnsComponent, i83.HeaderComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HeaderModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_GRID_HEADER_EXPORTS],
                    imports: [...importedModules, ...KENDO_GRID_HEADER_EXPORTS],
                    providers: [
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        NavigationService
                    ]
                }]
        }] });
