/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnInit, OnDestroy, ChangeDetectorRef } from '@angular/core';
import { PagerContextService, PagerContextChanges } from "./pager-context.service";
import { GridSize } from '../common/size-options';
import { ContextService } from '../common/provider.service';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare abstract class PagerElementComponent implements OnInit, OnDestroy {
    private ctx;
    protected pagerContext: PagerContextService;
    protected cd: ChangeDetectorRef;
    total: number;
    skip: number;
    pageSize: number;
    caretAltLeftIcon: SVGIcon;
    caretAltToLeftIcon: SVGIcon;
    caretAltRightIcon: SVGIcon;
    caretAltToRightIcon: SVGIcon;
    /**
     * Sets the pager element sizing option.
     * @default `medium`
     */
    size: GridSize;
    /**
     * @hidden
     *
     * @readonly
     * @type {number}
     * @memberOf PagerElementComponent
     */
    get currentPage(): number;
    /**
     * @hidden
     *
     * @readonly
     * @type {number}
     * @memberOf PagerElementComponent
     */
    get totalPages(): number;
    private subscriptions;
    constructor(ctx: ContextService, pagerContext: PagerContextService, cd: ChangeDetectorRef);
    /**
     * @hidden
     *
     * @param {string} key
     * @returns {string}
     *
     * @memberOf PagerElementComponent
     */
    textFor(key: string): string;
    /**
     * @hidden
     *
     * @param {number} page
     *
     * @memberOf PagerElementComponent
     */
    changePage(page: number): boolean;
    /**
     * @hidden
     *
     * @memberOf PagerElementComponent
     */
    ngOnInit(): void;
    protected abstract onChanges(changes: PagerContextChanges): void;
    ngOnDestroy(): void;
    get prevArrowIcons(): string[];
    get prevArrowSVGIcons(): SVGIcon[];
    get nextArrowIcons(): string[];
    get nextArrowSVGIcons(): SVGIcon[];
    static ɵfac: i0.ɵɵFactoryDeclaration<PagerElementComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PagerElementComponent, never, never, { "size": { "alias": "size"; "required": false; }; }, {}, never, never, false, never>;
}
