/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, OnChanges, SimpleChanges, OnInit, OnDestroy, ElementRef, Renderer2, NgZone } from '@angular/core';
import { PagerSettings } from './pager-settings';
import { PageChangeEvent } from '../data/change-event-args.interface';
import { PagerTemplateDirective } from './pager-template.directive';
import { PagerContextService } from './pager-context.service';
import { NavigationService } from '../navigation/navigation.service';
import { CellContext } from '../rendering/common/cell-context';
import { FocusGroup } from '../navigation/focus-group';
import { FocusRoot } from '../navigation/focus-root';
import { GridSize } from '../common/size-options';
import { ContextService } from '../common/provider.service';
import { PagerNumericButtonsComponent } from './pager-numeric-buttons.component';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class PagerComponent implements OnChanges, OnInit, OnDestroy {
    private pagerContext;
    navigationService: NavigationService;
    private element;
    private renderer;
    private zone;
    private ctx;
    private cellContext;
    private focusRoot;
    private focusGroup;
    pagerInfo: ElementRef;
    pagerPageSizes: ElementRef;
    numericButtons: PagerNumericButtonsComponent;
    total: number;
    skip: number;
    pageSize: number;
    set options(value: PagerSettings | boolean);
    set size(size: GridSize);
    get size(): GridSize;
    template: PagerTemplateDirective;
    pageChange: EventEmitter<PageChangeEvent>;
    gridPagerClass: boolean;
    get sizeSmallClass(): boolean;
    get sizeMediumClass(): boolean;
    settings: PagerSettings;
    private subscriptions;
    private _templateContext;
    private _isFocused;
    private _size;
    get isFocused(): boolean;
    get pagerAriaLabel(): string;
    get pagerLabel(): string;
    get focusTrapTabIndex(): string;
    onFocusIn(event: any): void;
    onFocusOut(): void;
    onEscape(): void;
    onEnter(event: any): void;
    navigateToPreviousPage(e: any): void;
    navigateToNextPage(e: any): void;
    navigateToFirstPage(e: any): void;
    navigateToLastPage(e: any): void;
    get totalPages(): number;
    get currentPage(): number;
    get templateContext(): any;
    constructor(pagerContext: PagerContextService, navigationService: NavigationService, element: ElementRef, renderer: Renderer2, zone: NgZone, ctx: ContextService, cellContext: CellContext, focusRoot: FocusRoot, focusGroup: FocusGroup);
    ngOnInit(): void;
    ngDoCheck(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    changePage(event: PageChangeEvent): void;
    resizeHandler: () => void;
    onInnerFocusIn(event: FocusEvent, position: string): void;
    private shouldTriggerPageChange;
    private focusFirstElement;
    private focusLastElement;
    private updateCellContext;
    private clearResponsiveStyling;
    static ɵfac: i0.ɵɵFactoryDeclaration<PagerComponent, [null, null, null, null, null, null, { optional: true; }, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PagerComponent, "kendo-pager", never, { "total": { "alias": "total"; "required": false; }; "skip": { "alias": "skip"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; "options": { "alias": "options"; "required": false; }; "size": { "alias": "size"; "required": false; }; "template": { "alias": "template"; "required": false; }; }, { "pageChange": "pageChange"; }, never, never, true, never>;
}
