/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Renderer2, ElementRef, OnDestroy, AfterContentChecked, OnChanges, EventEmitter, NgZone } from '@angular/core';
import { SelectionService } from './selection.service';
import { SelectAllCheckboxState } from './types';
import { CellSelectionService } from './cell-selection.service';
import * as i0 from "@angular/core";
/**
 * Represents the select-all checkbox feature of the Grid ([see example](slug:grid_selection_persistence#toc-selecting-all-items)).
 *
 * @example
 * ```html
 * <input
 *   type="checkbox"
 *   kendoCheckBox
 *   kendoGridSelectAllCheckbox
 *   [state]="selectAllState"
 *   (selectAllChange)="onSelectAllChange($event)"
 * />
 * ```
 */
export declare class SelectAllCheckboxDirective implements AfterContentChecked, OnDestroy, OnChanges {
    private selectionService;
    private cellSelectionService;
    private el;
    private renderer;
    private ngZone;
    /**
     * Explicitly overrides the state of the select-all checkbox.
     */
    state: SelectAllCheckboxState;
    /**
     * Fires when the user clicks the `kendoGridSelectAllCheckbox` select-all checkbox
     * ([see example](slug:grid_row_selection#toc-select-all-checkbox)).
     */
    selectAllChange: EventEmitter<SelectAllCheckboxState>;
    type: string;
    private destroyClick;
    private stateSet;
    ngAfterContentChecked(): void;
    ngOnChanges(): void;
    constructor(selectionService: SelectionService, cellSelectionService: CellSelectionService, el: ElementRef, renderer: Renderer2, ngZone: NgZone);
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onClick(): void;
    /**
     * @hidden
     */
    private setState;
    /**
     * @hidden
     */
    private stateToBool;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectAllCheckboxDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SelectAllCheckboxDirective, "[kendoGridSelectAllCheckbox]", never, { "state": { "alias": "state"; "required": false; }; }, { "selectAllChange": "selectAllChange"; }, never, never, true, never>;
}
